/*
+----------------------------------------------------------------------+
| (c) Copyright IBM Corporation 2006.                                  |
| All Rights Reserved.                                                 |
+----------------------------------------------------------------------+
|                                                                      |
| Licensed under the Apache License, Version 2.0 (the "License"); you  |
| may not use this file except in compliance with the License. You may |
| obtain a copy of the License at                                      |
| http://www.apache.org/licenses/LICENSE-2.0                           |
|                                                                      |
| Unless required by applicable law or agreed to in writing, software  |
| distributed under the License is distributed on an "AS IS" BASIS,    |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or      |
| implied. See the License for the specific language governing         |
| permissions and limitations under the License.                       |
+----------------------------------------------------------------------+
| Authors: Dave Renshaw, Jerry Stevens                                 |
+----------------------------------------------------------------------+

   $Id: SAM_Connection.h,v 1.1 2006/11/08 12:02:08 dsr Exp $

*/

#if !defined(__SAMPHPCONN_H__)
#define __SAMPHPCONN_H__

#include "php_sam.h"

#include <xms.h>

/* Resource struct...                       */
typedef struct _php_sam_connection {
    xmsHConn  conn;
} php_sam_connection;


extern function_entry sam_conn_functions[];

PHP_NAMED_FUNCTION(SAM_Connection_ctor);
PHP_FUNCTION(SAM_Connection_commit);
PHP_FUNCTION(SAM_Connection_connect);
PHP_FUNCTION(SAM_Connection_disconnect);
PHP_FUNCTION(SAM_Connection_isConnected);
PHP_FUNCTION(SAM_Connection_peek);
PHP_FUNCTION(SAM_Connection_receive);
PHP_FUNCTION(SAM_Connection_remove);
PHP_FUNCTION(SAM_Connection_rollback);
PHP_FUNCTION(SAM_Connection_send);
PHP_FUNCTION(SAM_Connection_subscribe);
PHP_FUNCTION(SAM_Connection_unsubscribe);

/* Oddball constants             */
#define SAM_CONNECTION_CONNECTION_INDEX  "__CONNECTION"

#define SAM_CONNECTION_PROTOCOL_SEPERATOR ':'

/* Error codes and messages    */
#define SAM_CONNECTION_WRONG_PARAMETERS_CONNECT        101
#define SAM_CONNECTION_WRONG_PARAMETERS_CONNECT_MSG    "Incorrect number of parameters on connect call!"
#define SAM_CONNECTION_UNSUPPORTED_PROTOCOL            102
#define SAM_CONNECTION_UNSUPPORTED_PROTOCOL_MSG        "Unsupported protocol!"
#define SAM_CONNECTION_UNSUPPORTED_PROTOCOL_OPTION     103
#define SAM_CONNECTION_UNSUPPORTED_PROTOCOL_OPTION_MSG "Unsupported protocol option!"
#define SAM_CONNECTION_WRONG_PARAMETERS_RECEIVE        104
#define SAM_CONNECTION_WRONG_PARAMETERS_RECEIVE_MSG    "Incorrect number of parameters on receive call!"
#define SAM_CONNECTION_WRONG_PARAMETERS_SEND           105
#define SAM_CONNECTION_WRONG_PARAMETERS_SEND_MSG       "Incorrect number of parameters on send call!"
#define SAM_CONNECTION_NO_CONNECTION                   106
#define SAM_CONNECTION_NO_CONNECTION_MSG               "No currently active XMS connection!"
#define SAM_CONNECTION_INVALID_MESSAGE                 107
#define SAM_CONNECTION_INVALID_MESSAGE_MSG             "Parameter 2 is not a SAM_Message object!"
#define SAM_CONNECTION_NO_ERROR_BLOCK                  201
#define SAM_CONNECTION_NO_ERROR_BLOCK_MSG              "Unable to create XMS error block!"
#define SAM_CONNECTION_NO_CONNECTION_FACTORY           202
#define SAM_CONNECTION_NO_CONNECTION_FACTORY_MSG       "Unable to create XMS connection factory!"
#define SAM_CONNECTION_SET_CONNECTION_TYPE             203
#define SAM_CONNECTION_SET_CONNECTION_TYPE_MSG         "Unable to set XMS connection type property!"
#define SAM_CONNECTION_SET_CONNECTION_MODE             204
#define SAM_CONNECTION_SET_CONNECTION_MODE_MSG         "Unable to set XMS connection mode property!"
#define SAM_CONNECTION_SET_HOST_NAME                   205
#define SAM_CONNECTION_SET_HOST_NAME_MSG               "Unable to set XMS host name property!"
#define SAM_CONNECTION_SET_PORT                        206
#define SAM_CONNECTION_SET_PORT_MSG                    "Unable to set XMS port property!"
#define SAM_CONNECTION_SET_QUEUE_MANAGER_NAME          207
#define SAM_CONNECTION_SET_QUEUE_MANAGER_NAME_MSG      "Unable to set XMS host queue manager property!"
#define SAM_CONNECTION_CONNECTION_CREATE               208
#define SAM_CONNECTION_CONNECTION_CREATE_MSG           "Unable to create XMS connection!"
#define SAM_CONNECTION_NO_DESTINATION                  209
#define SAM_CONNECTION_NO_DESTINATION_MSG              "Unable to create XMS destination!"
#define SAM_CONNECTION_NO_SESSION                      210
#define SAM_CONNECTION_NO_SESSION_MSG                  "Unable to create XMS session!"
#define SAM_CONNECTION_NO_CONSUMER                     211
#define SAM_CONNECTION_NO_CONSUMER_MSG                 "Unable to create XMS consumer!"
#define SAM_CONNECTION_RECEIVE_FAILED                  212
#define SAM_CONNECTION_RECEIVE_FAILED_MSG              "XMS receive failed!"
#define SAM_CONNECTION_NO_PRODUCER                     213
#define SAM_CONNECTION_NO_PRODUCER_MSG                 "Unable to create XMS producer!"
#define SAM_CONNECTION_NO_BYTES_MESSAGE                214
#define SAM_CONNECTION_NO_BYTES_MESSAGE_MSG            "Unable to create XMS bytes message!"
#define SAM_CONNECTION_WRITE_UTF_FAILED                215
#define SAM_CONNECTION_WRITE_UTF_FAILED_MSG            "Unable to write UTF data to XMS bytes message!"
#define SAM_CONNECTION_SEND_FAILED                     216
#define SAM_CONNECTION_SEND_FAILED_MSG                 "XMS send failed!"
#define SAM_CONNECTION_SET_CONNECTION_PROTOCOL         217
#define SAM_CONNECTION_SET_CONNECTION_PROTOCOL_MSG     "Unable to set connection protocol property!"
#define SAM_CONNECTION_CONNECTION_START                218
#define SAM_CONNECTION_CONNECTION_START_MSG            "Unable to start XMS connection!"
#define SAM_CONNECTION_NO_MSG_BODY                     219
#define SAM_CONNECTION_NO_MSG_BODY_MSG                 "No body property defined in SAM_Message object!"
#define SAM_CONNECTION_DISCONNECT_FAILED               220
#define SAM_CONNECTION_DISCONNECT_FAILED_MSG           "XMS connection close failed!"
#define SAM_CONNECTION_NO_MSG_ID                       221
#define SAM_CONNECTION_NO_MSG_ID_MSG                   "Could not retrieve message ID of sent message!"
#define SAM_CONNECTION_SET_CORRELID_FAILED             222
#define SAM_CONNECTION_SET_CORRELID_FAILED_MSG         "XMS set JMSCorrelationID failed!"
#define SAM_CONNECTION_READBYTES_FAILED                223
#define SAM_CONNECTION_READBYTES_FAILED_MSG            "XMS read of UTF from message failed!"
#define SAM_CONNECTION_SET_ENDPOINTS                   224
#define SAM_CONNECTION_SET_ENDPOINTS_MSG               "XMS set endpoints on Connection Factory failed!"
#define SAM_CONNECTION_SET_BUS                         225
#define SAM_CONNECTION_SET_BUS_MSG                     "XMS set bus name on Connection Factory failed!"
#define SAM_CONNECTION_NO_REPLY_DESTINATION            226
#define SAM_CONNECTION_NO_REPLY_DESTINATION_MSG        "Unable to create XMS destination for SAM_REPLY_TO value!"
#define SAM_CONNECTION_REPLY_TO_SET_FAILED             227
#define SAM_CONNECTION_REPLY_TO_SET_FAILED_MSG         "Unable to set JMSReplyTo property!"
#define SAM_CONNECTION_SET_PROPERTY_FAILED             228
#define SAM_CONNECTION_SET_PROPERTY_FAILED_MSG         "Unable to set user property on message!"
#define SAM_CONNECTION_PROPERTY_ARRAY_INVALID          239
#define SAM_CONNECTION_PROPERTY_ARRAY_INVALID_MSG      "Property incorrectly specified. Should have 2 entries (value, typeString)!"
#define SAM_CONNECTION_PROPERTY_GET_NAME_FAILED        240
#define SAM_CONNECTION_PROPERTY_GET_NAME_FAILED_MSG    "Unable to retrieve XMS property name from message!"
#define SAM_CONNECTION_PROPERTY_GET_STRING_FAILED      241
#define SAM_CONNECTION_PROPERTY_GET_STRING_FAILED_MSG  "Unable to retrieve XMS property value as string from message!"
#define SAM_CONNECTION_MESSAGE_PROPERTY_SET_FAILED     242
#define SAM_CONNECTION_MESSAGE_PROPERTY_SET_FAILED_MSG "Unable to set property into SAM message!"
#define SAM_CONNECTION_HEADER_CREATE_FAILED            243
#define SAM_CONNECTION_HEADER_CREATE_FAILED_MSG        "Unable to create header property in message!"
#define SAM_CONNECTION_ILLEGAL_DELIVERY_MODE           244
#define SAM_CONNECTION_ILLEGAL_DELIVERY_MODE_MSG       "Illegal value for delivery mode!"
#define SAM_CONNECTION_ILLEGAL_PRIORITY                245
#define SAM_CONNECTION_ILLEGAL_PRIORITY_MSG            "Illegal value for priority!"
#define SAM_CONNECTION_SET_DELIVERY_MODE               246
#define SAM_CONNECTION_SET_DELIVERY_MODE_MSG           "Unable to set the XMS delivery mode!"
#define SAM_CONNECTION_SET_PRIORITY                    247
#define SAM_CONNECTION_SET_PRIORITY_MSG                "Unable to set the priority on the XMS message producer!"
#define SAM_CONNECTION_WRITE_BYTES_FAILED              248
#define SAM_CONNECTION_WRITE_BYTES_FAILED_MSG          "Unable to write UTF data to XMS bytes message!"
#define SAM_CONNECTION_ILLEGAL_TIMETOLIVE              249
#define SAM_CONNECTION_ILLEGAL_TIMETOLIVE_MSG          "Illegal value for time to live!"
#define SAM_CONNECTION_SET_TIMETOLIVE                  250
#define SAM_CONNECTION_SET_TIMETOLIVE_MSG              "Unable to set time to live on the XMS message producer!"
#define SAM_CONNECTION_MSG_TYPE_INVALID                251
#define SAM_CONNECTION_MSG_TYPE_INVALID_MSG            "Value specified for SAM_TYPE property not recognised!"
#define SAM_CONNECTION_NO_TEXT_MESSAGE                 252
#define SAM_CONNECTION_NO_TEXT_MESSAGE_MSG             "Unable to create XMS text message!"
#define SAM_CONNECTION_WRITE_TEXT_FAILED               253
#define SAM_CONNECTION_WRITE_TEXT_FAILED_MSG           "Unable to write string data to XMS text message!"
#define SAM_CONNECTION_TYPE_GET_FAILED                 254
#define SAM_CONNECTION_TYPE_GET_FAILED_MSG             "Unable to get message type!"
#define SAM_CONNECTION_GETTEXT_FAILED                  255
#define SAM_CONNECTION_GETTEXT_FAILED_MSG              "XMS get of text from message failed!"


#endif /*__SAMPHPCONN_H__) */


