/*
+----------------------------------------------------------------------+
| (c) Copyright IBM Corporation 2006.                                  |
| All Rights Reserved.                                                 |
+----------------------------------------------------------------------+
|                                                                      |
| Licensed under the Apache License, Version 2.0 (the "License"); you  |
| may not use this file except in compliance with the License. You may |
| obtain a copy of the License at                                      |
| http://www.apache.org/licenses/LICENSE-2.0                           |
|                                                                      |
| Unless required by applicable law or agreed to in writing, software  |
| distributed under the License is distributed on an "AS IS" BASIS,    |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or      |
| implied. See the License for the specific language governing         |
| permissions and limitations under the License.                       |
+----------------------------------------------------------------------+
| Authors: Dave Renshaw, Jerry Stevens                                 |
+----------------------------------------------------------------------+

   $Id: php_sam.h,v 1.1 2006/11/08 12:02:08 dsr Exp $

*/

#if !defined(__SAM_PHP_H__)
#define __SAM_PHP_H__

/***************************************************************************/
/*                                                                         */
/* Import / export definitions                                             */
/*                                                                         */
/***************************************************************************/

#ifdef ZTS
#   include <TSRM.h>
#endif

#ifdef PHP_WIN32
#   define PHP_XMS_API __declspec(dllexport)
#else
#   define PHP_XMS_API
#endif

/***************************************************************************/
/*                                                                         */
/* Global definitions used elsewhere. As these are global, they may be     */
/* referenced by other header files locally.                               */
/*                                                                         */
/***************************************************************************/

/*
 * This is the name by which the PHP module is known. Theuser tests for the
 * module being loaded with the code: if ( extension_loaded('sam') ) { ... }
 */

#define SAM__MODULE_NAME            "sam"
#define SAM__MODULE_VERSION         "0.1"

#define PHP_SAM_CONNECTION_RES_NAME "__SAM_XMS_Connection_pointer"

/* SAM constants                                                          */
/* property types                                                         */
#define SAM_CONSTANT_BOOLEAN        "bool"
#define SAM_CONSTANT_BYTE           "byte"
#define SAM_CONSTANT_DOUBLE         "double"
#define SAM_CONSTANT_FLOAT          "float"
#define SAM_CONSTANT_INTEGER        "int"
#define SAM_CONSTANT_LONG           "long"
#define SAM_CONSTANT_STRING         "string"

/* property names                                                         */
#define SAM_CONSTANT_BROKER         "SAM_BROKER"
#define SAM_CONSTANT_BUS            "SAM_BUS"
#define SAM_CONSTANT_DELIVERYMODE   "SAM_DELIVERYMODE"
#define SAM_CONSTANT_ENDPOINTS      "SAM_ENDPOINTS"
#define SAM_CONSTANT_HOST           "SAM_HOST"
#define SAM_CONSTANT_MSGPRIORITY    "SAM_MSGPRIORITY"
#define SAM_CONSTANT_PASSWORD       "SAM_PASSWORD"
#define SAM_CONSTANT_PORT           "SAM_PORT"
#define SAM_CONSTANT_PRIORITY       "SAM_PRIORITY"
#define SAM_CONSTANT_REPLY_TO       "SAM_REPLY_TO"
#define SAM_CONSTANT_SELECT         "SAM_SELECT"
#define SAM_CONSTANT_TARGETCHAIN    "SAM_TARGETCHAIN"
#define SAM_CONSTANT_TIMETOLIVE     "SAM_TIMETOLIVE"
#define SAM_CONSTANT_TRANSACTIONS   "SAM_TRANSACTIONS"
#define SAM_CONSTANT_TYPE           "SAM_TYPE"
#define SAM_CONSTANT_USERID         "SAM_USERID"
#define SAM_CONSTANT_WAIT           "SAM_WAIT"

/* property values                                                         */
#define SAM_CONSTANT_AUTO           "auto"
#define SAM_CONSTANT_BYTES          "SAM_BYTES"
#define SAM_CONSTANT_MANUAL         "manual"
#define SAM_CONSTANT_NONPERSISTENT  "nonpersistent"
#define SAM_CONSTANT_PERSISTENT     "persistent"
#define SAM_CONSTANT_TEXT           "SAM_TEXT"
#define SAM_CONSTANT_UNKNOWN        "SAM_UNKNOWN"

/* protocols                                                               */
#define SAM_CONSTANT_RTT            "rtt"
#define SAM_CONSTANT_WMQ            "wmq"
#define SAM_CONSTANT_WMQ_CLIENT     "wmq:client"
#define SAM_CONSTANT_WMQ_BINDINGS   "wmq:bindings"
#define SAM_CONSTANT_WPM            "wpm"

#define SAM_CONSTANT_OPTION_CLIENT   "client"
#define SAM_CONSTANT_OPTION_BINDINGS "bindings"

/***************************************************************************/
/*                                                                         */
/* Individual include files for each PHP class                             */
/*                                                                         */
/***************************************************************************/

#include "SAM_Connection.h"
#include "SAM_Message.h"

PHP_FUNCTION(sam_debug_off);
PHP_FUNCTION(sam_debug_on);

/*
 * Force the module entry point to be "extern"
 */
extern zend_module_entry sam_module_entry;
#define phpext_sam_ptr &sam_module_entry

/***************************************************************************/
/*                                                                         */
/* Function prototypes for the module                                      */
/*                                                                         */
/***************************************************************************/

/*
 * Module initialisation function
 */
PHP_MINIT_FUNCTION(sam);

/*
 * Module shutdown funciton
 */
PHP_MSHUTDOWN_FUNCTION(sam);


/*
 * Module request initialisation function
 */
PHP_RINIT_FUNCTION(sam);

/*
 * Module request shutdown function
 */
PHP_RSHUTDOWN_FUNCTION(sam);

PHP_MINFO_FUNCTION(sam);



/***************************************************************************/
/*                                                                         */
/* Useful macros                                                           */
/*                                                                         */
/***************************************************************************/

/*
ZEND_BEGIN_MODULE_GLOBALS(sam)
        long  global_value;
        char *global_string;
ZEND_END_MODULE_GLOBALS(sam)
*/


#endif
